"""Command line interface for PyHLD."""
import click
from rich.console import Console
from rich.panel import Panel
from . import __version__

console = Console()

@click.group()
@click.version_option(version=__version__)
def main():
    """PyHLD - Fiber to the Home High Level Design CLI Tool."""
    pass

@main.command()
@click.option('--input-file', '-i', type=click.Path(exists=True), help='Input data file')
@click.option('--output', '-o', type=click.Path(), help='Output file path')
def design(input_file, output):
    """Create a high-level FTTH design."""
    console.print(Panel.fit("🌐 Creating FTTH Design", title="PyHLD"))
    console.print(f"Input file: {input_file}")
    console.print(f"Output will be saved to: {output}")

@main.command()
@click.option('--homes', '-h', type=int, help='Number of homes to be served')
@click.option('--area', '-a', type=float, help='Service area in square kilometers')
def calculate(homes, area):
    """Calculate basic FTTH metrics."""
    console.print(Panel.fit("📊 Calculating FTTH Metrics", title="PyHLD"))
    if homes and area:
        density = homes / area
        console.print(f"Homes: {homes}")
        console.print(f"Area: {area} km²")
        console.print(f"Density: {density:.2f} homes/km²")

@main.command()
def validate():
    """Validate design parameters and constraints."""
    console.print(Panel.fit("✅ Validating Design", title="PyHLD"))
    # Add validation logic here

if __name__ == '__main__':
    main()